/*
 *  Authors:  tiandongdong <tiandongdong@kylinos.cn>
 *  Authors:  litianhao <litianhao@kylinos.cn>
 *
 *  Copyright (c) KylinSoft Co., Ltd [2024].All rights reserved.
 */
#pragma once

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief 接口调用结果
 */
enum KYSEC_SCENE_CALL_RESULT {
    /**
     * @brief 成功
     */
    KYSEC_SCENE_OK = 0,

    /**
     * @brief 参数无效
     * @detail 可能有空指针，或者参数数值不在允许范围内
     */
    KYSEC_SCENE_ERR_INVALID_PARAMETER = -1,

    /**
     * @brief 策略已存在
     * @detail 尝试添加策略时，已存在相同策略
     */
    KYSEC_SCENE_ERR_POLICY_ALREADY_EXISTS = -2,

    /**
     * @brief 策略不存在
     * @detail 尝试删除策略时，未找到要删除的策略
     */
    KYSEC_SCENE_ERR_POLICY_NOT_EXISTS = -3,

    /**
     * @brief 没有权限
     */
    KYSEC_SCENE_ERR_PERMISSION_DENIED = -4,

    /**
     * @brief 内部错误
     */
    KYSEC_SCENE_ERR_INTERNAL = -100,
};

enum kysec_module_type {
    KYSEC_EXECTL,            /* 执行控制功能 */
    KYSEC_NETCTL,            /* 网络管控功能 */
    KYSEC_FILECTL,           /* 文件防护功能 */
    KYSEC_KMODCTL,           /* 内核模块防卸载功能 */
    KYSEC_ADMCTL,            /* 三权分立功能 */
    KYSEC_TASKCTL,           /* 进程防护功能 */
    KYSEC_DEVCTL,            /* 设备管控功能 */
    KYSEC_EXECTL_SCRIPT,     /* 脚本的执行控制功能 */
    KYSEC_EXECTL_TEMPORARY,  /* 临时文件执行控制功能 */
    KYSEC_STATIC_MEASURECTL, /* 静态度量功能 */
    KYSEC_PBLKCTL,           /* 进程黑名单功能 */
    KYSEC_BOXCTL,            /* 文件保护箱功能 */
    KYSEC_ACCESSCTL,         /* 应用访问控制功能 */
    KYSEC_KIDCTL,            /* 用户隐私数据功能*/
};

enum kysec_module_status_type {
    /* 模块关闭状态 */
    KYSEC_MODULE_DISABLE,
    /* 模块开启状态 */
    KYSEC_MODULE_ENABLE,
    /* 模块告警状态(仅netctl exectl devctl可设置该状态) */
    KYSEC_MODULE_ALARM,
};

enum kysec_status_type {
    KYSEC_STATUS_DISABLE,
    KYSEC_STATUS_ENABLE = 2,
    KYSEC_STATUS_PERMISSIVE = 4,
};

enum kysec_effective_time_type {
    KYSEC_EFFECTIVE_PERMANENT = 1,
    KYSEC_EFFECTIVE_TEMPORARY = 2,

};

/**
 * @brief 设置kysec模块管控状态
 * @param module 模块
 * @param status 状态
 * @return 0:成功 其他:失败
 */
int kysec_scene_set_module_status(enum kysec_module_type module,
                                  enum kysec_module_status_type status);

/**
 * @brief 设置多个模块状态
 * @param module 模块
 * @param status 状态
 * @param sync_policy 是否同步 0:不同步策略 仅仅只更改json文件 1:同步策略
 * @return 0:成功 其他:失败
 */
int kysec_scene_set_multi_module_status(enum kysec_module_type module,
                                        enum kysec_module_status_type status,
                                        int sync_policy);

/**
 * @brief 获取kysec模块管控状态
 * @param module 模块
 * @return 0:关闭 1:开启 2:告警(仅devctl netctl exectl) 其他:获取失败
 */
int kysec_scene_get_module_status(enum kysec_module_type module);

/**
 * @brief 获取kysec安全机制总体状态
 * @return 0:关闭 2:强制模式 4:软模式
 */
int kysec_scene_getstatus(void);

/**
 * @brief 设置kysec安全机制状态
 * @param status 状态值
 * @param effective_time 有效时间
 * @return 0:成功 其他:失败
 */
int kysec_scene_setstatus(enum kysec_status_type status,
                          enum kysec_effective_time_type effective_time);

/**
 * @brief 获取sm状态
 * @return 0:关闭 1:开启
 */
int kysec_scene_get_sm_status(void);

/**
 * @brief 获取标记设置状态 (用于上层调用判断是否需要重启系统)
 * @return 0:成功 1:标记设置失败(需要重启) -1: dbus错误
 */
int kysec_scene_get_label_set_status(void);

/**
 * @brief 编译策略(用于ksaf未初始化时,编译策略调用)
 * @return 0:成功 其他:失败
 */
int kysec_scene_compile_init_policy(void);
#ifdef __cplusplus
}
#endif
